@@ -58,11 +58,14 @@ from .loader import load_url  # noqa
 from .manifest_provider.cache import CachedManifestProvider, CachedSourceManifestProvider  # noqa
 
 
-__version__ = '0.6.6'  # same version as in setup.py
+# same version as in:
+# - setup.py
+# - stdeb.cfg
+__version__ = '0.8.0'
 
 # index information
 
-DEFAULT_INDEX_URL = 'https://raw.githubusercontent.com/ros/rosdistro/master/index.yaml'
+DEFAULT_INDEX_URL = 'https://raw.githubusercontent.com/ros/rosdistro/master/index-v4.yaml'
 
 
 def get_index_url():
@@ -73,7 +76,7 @@ def get_index_url():
     def read_cfg_index_url(fname):
         try:
             with open(fname) as f:
-                return yaml.load(f.read())['index_url']
+                return yaml.safe_load(f.read())['index_url']
         except (IOError, KeyError, yaml.YAMLError):
             return None
 
@@ -99,7 +102,7 @@ def get_index_url():
 def get_index(url):
     logger.debug('Load index from "%s"' % url)
     yaml_str = load_url(url)
-    data = yaml.load(yaml_str)
+    data = yaml.safe_load(yaml_str)
     base_url = os.path.dirname(url)
     url_parts = urlparse(url)
     return Index(data, base_url, url_query=url_parts.query)
@@ -146,7 +149,7 @@ def get_cached_distribution(index, dist_name, cache=None, allow_lazy_load=False)
     return dist
 
 
-def get_distribution_cache(index, dist_name):
+def get_distribution_cache_string(index, dist_name):
     if dist_name not in index.distributions.keys():
         raise RuntimeError("Unknown distribution: '{0}'. Valid distribution names are: {1}".format(dist_name, ', '.join(sorted(index.distributions.keys()))))
     dist = index.distributions[dist_name]
@@ -162,12 +165,17 @@ def get_distribution_cache(index, dist_name):
         yaml_gz_stream = StringIO(yaml_gz_str)
         f = gzip.GzipFile(fileobj=yaml_gz_stream, mode='rb')
         yaml_str = f.read()
+        f.close()
         if not isinstance(yaml_str, str):
             yaml_str = yaml_str.decode('utf-8')
-        f.close()
     else:
         raise NotImplementedError('The url of the cache must end with either ".yaml" or ".yaml.gz"')
-    data = yaml.load(yaml_str)
+    return yaml_str
+
+
+def get_distribution_cache(index, dist_name):
+    yaml_str = get_distribution_cache_string(index, dist_name)
+    data = yaml.safe_load(yaml_str)
     return DistributionCache(dist_name, data)
 
 
@@ -184,7 +192,7 @@ def _get_dist_file_data(index, dist_name, type_):
     def _load_yaml_data(url):
         logger.debug('Load file from "%s"' % url)
         yaml_str = load_url(url)
-        return yaml.load(yaml_str)
+        return yaml.safe_load(yaml_str)
 
     if not isinstance(url, list):
         data = _load_yaml_data(url)
