@@ -18,6 +18,9 @@ def test_get_index_v2():
     assert len(i.distributions.keys()) == 1
     assert 'foo' in i.distributions.keys()
 
+    assert 'distribution_status' not in i.distributions['foo']
+    assert 'distribution_type' not in i.distributions['foo']
+
 
 def test_get_index_v3():
     url = 'file://' + FILES_DIR + '/index_v3.yaml'
@@ -25,6 +28,9 @@ def test_get_index_v3():
     assert len(i.distributions.keys()) == 1
     assert 'foo' in i.distributions.keys()
 
+    assert 'distribution_status' not in i.distributions['foo']
+    assert 'distribution_type' not in i.distributions['foo']
+
     dist_files = get_distribution_files(i, 'foo')
     assert len(dist_files) == 2
     get_distribution_file(i, 'foo')
@@ -43,6 +49,20 @@ def test_get_index_v3_invalid():
         pass
 
 
+def test_get_index_v4():
+    url = 'file://' + FILES_DIR + '/index_v4.yaml'
+    i = get_index(url)
+    assert len(i.distributions.keys()) == 1
+    assert 'foo' in i.distributions.keys()
+
+    assert i.distributions['foo']['distribution_status'] == 'active'
+    assert i.distributions['foo']['distribution_type'] == 'ros1'
+
+    dist_files = get_distribution_files(i, 'foo')
+    assert len(dist_files) == 2
+    get_distribution_file(i, 'foo')
+
+
 def test_get_index_from_http_with_query_parameters():
     import subprocess
     import sys
@@ -62,7 +82,9 @@ def test_get_index_from_http_with_query_parameters():
         assert 'foo' in i.distributions.keys()
 
         # test if every url has the same queries
-        for dist_urls in i.distributions['foo'].values():
+        for key, dist_urls in i.distributions['foo'].items():
+            if key in ('distribution_status', 'distribution_type'):
+                continue
             if not isinstance(dist_urls, list):
                 dist_urls = [dist_urls]
             for dist_url in dist_urls:
